FormatReadPlanStep

Enum FormatReadPlanStep 

#[non_exhaustive]
pub enum FormatReadPlanStep<'a, S: Storage + 'static> {
#[non_exhaustive]
Raw { storage: &'a S, offset: u64, image_offset: u64, len: u64, writable: bool, },
#[non_exhaustive]
Zero { image_offset: u64, len: u64, explicit: bool, },
#[non_exhaustive]
Eof { image_offset: u64, len: u64, },
#[non_exhaustive]
Special { layer: &'a FormatAccess<S>, offset: u64, image_offset: u64, len: u64, }, }
One step in a FormatReadPlan.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


#[non_exhaustive]
Raw

Range that can be read directly from a storage object.

Fields

This variant is marked as non-exhaustive
Non-exhaustive enum variants could have additional fields added in future. Therefore, non-exhaustive enum variants cannot be constructed in external crates and cannot be matched against.
storage: &'a S

Storage object where this data is stored.

offset: u64

Offset in storage where this data is stored.

image_offset: u64

Offset in the requested image where this step starts.

len: u64

Length of this step in bytes.

writable: bool

Whether this raw mapping may be written to directly.



#[non_exhaustive]
Zero

Range that should be returned as zeroes.

Fields

This variant is marked as non-exhaustive
Non-exhaustive enum variants could have additional fields added in future. Therefore, non-exhaustive enum variants cannot be constructed in external crates and cannot be matched against.
image_offset: u64

Offset in the requested image where this step starts.

len: u64

Length of this step in bytes.

explicit: bool

Whether these zeroes are explicit on the top format layer.



#[non_exhaustive]
Eof

Range beyond the image’s top-layer end of file.

Normal reads fill this range with zeroes.

Fields

This variant is marked as non-exhaustive
Non-exhaustive enum variants could have additional fields added in future. Therefore, non-exhaustive enum variants cannot be constructed in external crates and cannot be matched against.
image_offset: u64

Offset in the requested image where this step starts.

len: u64

Length of this step in bytes.



#[non_exhaustive]
Special

Range that must be interpreted by the image format driver.

Fields

This variant is marked as non-exhaustive
Non-exhaustive enum variants could have additional fields added in future. Therefore, non-exhaustive enum variants cannot be constructed in external crates and cannot be matched against.
layer: &'a FormatAccess<S>

Format layer where this special data was encountered.

offset: u64

Original offset on layer to pass to readv_special().

image_offset: u64

Offset in the requested image where this step starts.

len: u64

Length of this step in bytes.