FormatDriverBuilderBase

Struct FormatDriverBuilderBase 

pub struct FormatDriverBuilderBase<S: Storage> { /* private fields */ }
Image open builder with the most basic options.

Implementations

Source

impl<S: Storage + 'static> FormatDriverBuilderBase<S>

pub fn new(image: S) -> Self

pub fn new_path<P: AsRef<Path>>(path: P) -> Self

pub fn set_write(&mut self, writable: bool)

pub fn set_storage_open_options(&mut self, options: StorageOpenOptions)

pub fn get_image_path(&self) -> Option<PathBuf>

If possible, get the image’s path.

pub fn get_writable(&self) -> bool

Return the set writable state.

pub fn get_storage_opts(&self) -> Option<&StorageOpenOptions>

Return the set storage options (if any).

pub fn make_storage_opts(&self) -> StorageOpenOptions

Create storage options.

If any were set, return those, overriding their writable state based on the set writable state (FormatDriverBuilderBase::set_write()). Otherwise, create an empty set (again with the writable state set as appropriate).

pub async fn open_image<G: ImplicitOpenGate<S>>(self, gate: &mut G) -> Result<S>

Open the image’s storage object.