OneOrMany

Enum OneOrMany 

enum OneOrMany<T> {
    One(T),
    Many(Vec<T>),
}
Stores either one item inline or multiple items in a vector.

Variants



One(T)

A single item.



Many(Vec<T>)

Multiple items.

Implementations

Source

impl<T> OneOrMany<T>

fn from_exact_iter(items: impl ExactSizeIterator<Item = T>) -> Self

Collects an exact-size iterator, storing its sole item inline when possible.

fn unzip_exact<U>( items: impl ExactSizeIterator<Item = (T, U)>, ) -> (Self, OneOrMany<U>)

Unzips an exact-size iterator, storing sole items inline when possible.

fn as_slice(&self) -> &[T]

Returns the stored items as a slice.