VolatileSliceGuard

Struct VolatileSliceGuard 

pub struct VolatileSliceGuard<'a, PtrGuardType, BitmapType: Bitmap> { /* private fields */ }
Available on crate feature vm-memory only.
Ensures an I/O vector’s validity when created from [VolatileSlice].

[VolatileSlice] arrays may require being explicitly mapped before use (and unmapped after), and this guard ensures that the memory is mapped until it is dropped.

Further, for mutable vectors (IoVectorMut), it will also dirty the corresponding bitmap slices when dropped, assuming the whole vector has been written.