macro_rules! last_element {
($x:expr) => { ... };
($x:expr, $($tail:expr),+) => { ... };
}Expand description
Evaluate to the last element in the list, separated by commas.
macro_rules! last_element {
($x:expr) => { ... };
($x:expr, $($tail:expr),+) => { ... };
}Evaluate to the last element in the list, separated by commas.