Null

Struct Null 

pub struct Null { /* private fields */ }
Null storage object.

Reading from this will always return zeroes, writing to it does nothing (except to potentially grow its virtual “file length”).

Implementations

Source

impl Null

pub fn new(size: u64) -> Self

Create a new null storage object with the given initial virtual size.