enum CacheDependency {
None,
L2DependsOnRb,
RbDependsOnL2,
}Expand description
Current flush dependency direction between L2 and refblock caches
Variants
None
No dependency set yet
L2DependsOnRb
Write refblock cache before writing anything from the L2 cache (during cluster allocation)
RbDependsOnL2
Write L2 cache before writing anything from the refblock cache (during cluster freeing)