struct RangeBlockedList {
blocked: Vec<Arc<RangeBlocked>>,
}Expand description
A list of ranges blocked for some kind of concurrent access.
Depending on the use, some will block all concurrent access (i.e. serializing writes will block both serializing and non-serializing writes (strong blockers)), while others will only block a subset (non-serializing writes will only block serializing writes (weak blockers)).
Fields
blocked: Vec<Arc<RangeBlocked>>The list of ranges.
Serializing writes (strong write blockers) are supposed to be rare, so it is important that entering and removing items into/from this list is cheap, not that iterating it is.
Implementations
Sourceimpl RangeBlockedList
impl RangeBlockedList
Sourcefn collect_intersecting(
&self,
check_range: &Range<u64>,
intersecting: &mut FuturesUnordered<Receiver<()>>,
)
fn collect_intersecting( &self, check_range: &Range<u64>, intersecting: &mut FuturesUnordered<Receiver<()>>, )
Collects futures/receivers to await intersecting request.
Creates a channel for every intersecting request; blocking on the receiver will wait for the request to complete.