Function pure_write_full_zeroes

async unsafe fn pure_write_full_zeroes<S: Storage>(
    storage: S,
    offset: u64,
    length: u64,
) -> Result<()>
Write zero data to the given area.

Like ext::write_full_zeroes(), this will actually write zero data, fully allocated.

Safety

This is a pure write to storage. The request must be fully aligned to Storage::req_align(), and safeguards we want to implement for safe concurrent access may not be available.

To be used as the default implementation of Storage::pure_write_zeroes() and Storage::pure_write_allocated_zeroes().