enum OneOrMany<T> {
One(T),
Many(Vec<T>),
}Expand description
Stores either one item inline or multiple items in a vector.
Variants
Implementations
Sourceimpl<T> OneOrMany<T>
impl<T> OneOrMany<T>
Sourcefn from_exact_iter(items: impl ExactSizeIterator<Item = T>) -> Self
fn from_exact_iter(items: impl ExactSizeIterator<Item = T>) -> Self
Collects an exact-size iterator, storing its sole item inline when possible.
Sourcefn unzip_exact<U>(
items: impl ExactSizeIterator<Item = (T, U)>,
) -> (Self, OneOrMany<U>)
fn unzip_exact<U>( items: impl ExactSizeIterator<Item = (T, U)>, ) -> (Self, OneOrMany<U>)
Unzips an exact-size iterator, storing sole items inline when possible.